==> acf-freeswitch-vmail-0.1.0.tar.bz2: acf-freeswitch-vmail-0.1.0/vmail-controller.lua <==
module (..., package.seeall)

default_action = "listmessages"

listfolders = function( self )
	return self.model.list_folders()
end

listusers = function( self )
	return self.model.list_users()
end

editusers = function( self )
	return self.model.list_users()
end

deleteuser = function( self )
	return self.handle_form(self, self.model.get_delete_user, self.model.set_delete_user, self.clientdata, "Delete", "Delete User", "User Deleted")
end

listmessages = function( self )
	return self.model.list_messages(self.clientdata.username)
end

listmymessages = function( self )
	return self.model.list_messages(self.sessiondata.userinfo.userid)
end

downloadmessage = function( self )
	self.conf.viewtype = "stream"
	return self.model.get_message(self.clientdata.message)
end

downloadmymessage = function( self )
	self.conf.viewtype = "stream"
	return self.model.get_message(self.clientdata.message, self.sessiondata.userinfo.userid)
end

deletemessage = function( self )
	return self.handle_form(self, self.model.get_delete_message, self.model.set_delete_message, self.clientdata, "Delete", "Delete Message", "Message Deleted")
end

deletemymessage = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_delete_message, self.model.set_delete_message, self.clientdata, "Delete", "Delete Message", "Message Deleted")
end

forwardmessage = function( self )
	return self.handle_form(self, self.model.get_forward_message, self.model.forward_message, self.clientdata, "Forward", "Forward Message", "Message Forwarded")
end

forwardmymessage = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_forward_message, self.model.forward_message, self.clientdata, "Forward", "Forward Message", "Message Forwarded")
end

emailmessage = function( self )
	return self.handle_form(self, self.model.get_email_message, self.model.email_message, self.clientdata, "Email", "Email Message", "Message Emailed")
end

emailmymessage = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_email_message, self.model.email_message, self.clientdata, "Email", "Email Message", "Message Emailed")
end

movemessage = function( self )
	return self.handle_form(self, self.model.get_move_message, self.model.move_message, self.clientdata)
end

movemymessage = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_move_message, self.model.move_message, self.clientdata)
end

callbackmessage = function( self )
	return self.handle_form(self, self.model.get_callback_message, self.model.callback_message, self.clientdata)
end

callbackmymessage = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_callback_message, self.model.callback_message, self.clientdata)
end

editusersettings = function( self )
	return self.handle_form(self, self.model.get_usersettings, self.model.update_usersettings, self.clientdata, "Save", "Edit Settings", "Settings Saved")
end

editmyusersettings = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_usersettings, self.model.update_usersettings, self.clientdata, "Save", "Edit Settings", "Settings Saved")
end

createuser = function( self )
	return self.handle_form(self, self.model.get_usersettings, self.model.create_usersettings, self.clientdata, "Create", "Create User", "User Created")
end

processdialplanxml = function( self )
	self.conf.viewtype = "xml"
	return self.model.process_dialplan_xml_request(self.clientdata)
end

processdirectoryxml = function( self )
	self.conf.viewtype = "xml"
	return self.model.process_directory_xml_request(self.clientdata)
end

editconfig = function( self )
	return self.handle_form(self, self.model.get_config, self.model.update_config, self.clientdata, "Save", "Update Config", "Config Saved")
end

==> acf-freeswitch-vmail-0.2.0.tar.bz2: acf-freeswitch-vmail-0.2.0/vmail-controller.lua <==
module (..., package.seeall)

default_action = "listmessages"

listfolders = function( self )
	return self.model.list_folders()
end

listusers = function( self )
	return self.model.list_users()
end

editusers = function( self )
	return self.model.list_users()
end

deleteuser = function( self )
	return self.handle_form(self, self.model.get_delete_user, self.model.set_delete_user, self.clientdata, "Delete", "Delete User", "User Deleted")
end

listmessages = function( self )
	return self.model.list_messages(self.clientdata.username)
end

listmymessages = function( self )
	return self.model.list_messages(self.sessiondata.userinfo.userid)
end

downloadmessage = function( self )
	return self.model.get_message(self.clientdata.message)
end

downloadmymessage = function( self )
	return self.model.get_message(self.clientdata.message, self.sessiondata.userinfo.userid)
end

deletemessage = function( self )
	return self.handle_form(self, self.model.get_delete_message, self.model.set_delete_message, self.clientdata, "Delete", "Delete Message", "Message Deleted")
end

deletemymessage = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_delete_message, self.model.set_delete_message, self.clientdata, "Delete", "Delete Message", "Message Deleted")
end

forwardmessage = function( self )
	return self.handle_form(self, self.model.get_forward_message, self.model.forward_message, self.clientdata, "Forward", "Forward Message", "Message Forwarded")
end

forwardmymessage = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_forward_message, self.model.forward_message, self.clientdata, "Forward", "Forward Message", "Message Forwarded")
end

emailmessage = function( self )
	return self.handle_form(self, self.model.get_email_message, self.model.email_message, self.clientdata, "Email", "Email Message")
end

emailmymessage = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_email_message, self.model.email_message, self.clientdata, "Email", "Email Message")
end

movemessage = function( self )
	return self.handle_form(self, self.model.get_move_message, self.model.move_message, self.clientdata, "Move")
end

movemymessage = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_move_message, self.model.move_message, self.clientdata, "Move")
end

callbackmessage = function( self )
	return self.handle_form(self, self.model.get_callback_message, self.model.callback_message, self.clientdata, "Callme")
end

callbackmymessage = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_callback_message, self.model.callback_message, self.clientdata, "Callme")
end

editusersettings = function( self )
	return self.handle_form(self, self.model.get_usersettings, self.model.update_usersettings, self.clientdata, "Save", "Edit Settings", "Settings Saved")
end

editmyusersettings = function( self )
	self.clientdata.username = nil
	if self.sessiondata.userinfo then
		self.clientdata.username = self.sessiondata.userinfo.userid
	end
	return self.handle_form(self, self.model.get_usersettings, self.model.update_usersettings, self.clientdata, "Save", "Edit Settings", "Settings Saved")
end

createuser = function( self )
	return self.handle_form(self, self.model.get_usersettings, self.model.create_usersettings, self.clientdata, "Create", "Create User", "User Created")
end

processdialplanxml = function( self )
	self.conf.viewtype = "xml"
	return self.model.process_dialplan_xml_request(self.clientdata)
end

processdirectoryxml = function( self )
	self.conf.viewtype = "xml"
	return self.model.process_directory_xml_request(self.clientdata)
end

editconfig = function( self )
	return self.handle_form(self, self.model.get_config, self.model.update_config, self.clientdata, "Save", "Update Config", "Config Saved")
end
